<?php
/**
*** @name common.php
*** @description controller used for all application pages
*** 	- Instance Smarty Object ($smarty)
*** 	- Get language informations
*** 	- Initialise common pages elements (header, footer, menu, ...)
*** @author Quentin George <q.george@esia-sa.com>
*** @version 1.0.0
*** @date 19/04/2023
**/

$path = $_SERVER['DOCUMENT_ROOT'] . '/';
include_once $path . 'gesa.conf.php';
include_once MVCMODEL;
include_once USR_CLASS;
include_once GESA_CLASS;
include_once LIB_GESA;
include_once LIB_CONVERT;
require_once(LIB_SMARTY);

// Action
$action = '';
if(!empty($_GET['action']))
{
	$action = $_GET['action'];
}
elseif(!empty($_POST['action']))
{
	$action = $_POST['action'];
}

$errors = array();

session_start();

try
{
	// Create user object
	$user = new User(NULL);
}
catch(UserException | Exception $e)
{
	$errors[] = $e->getMessage();
}

// User check only if not on login page. Bypass login check for action changeLang
if($_SERVER['SCRIPT_NAME'] != '/login.php' && $action != 'changeLang')
{
	try
	{
		// Check login
		$user->sessionIDisValid();
	}
	catch(UserException $e)
	{
		// User not connected go to login page
		header('Location: /login.php');
		exit(0);
	}
}

try
{
	// Init smarty object
	$smarty = new Smarty();

	if(!empty($user->getName()))
	{
		$smarty->assign('logged_user_name', $user->getName());
	}

	// Get user DB default lang before modifications from session, ...
	$defaultUserLang = $user->getLang();
	$smarty->assign('defaultUserLang', $defaultUserLang);
	
	// Get user conf
	$userConf = getJsonConfFile($path . DATA_DIR . USER_CONF_FILE);
	// Get user default lang before modifications from session, ...
	$smarty->assign('defaultUserLang', $userConf['lang']);
	// Replace saved config by current session config
	if(isset($_SESSION['user_conf']))
	{
		$userConf = array_replace($userConf, $_SESSION['user_conf']);
	}
	
	// Configure lang variables
	$langAvailables = getLangAvailables($path . 'lang/');
	$lang_site = DEFAULT_LANG;
	if(!empty($userConf['lang']) && in_array($userConf['lang'], $langAvailables))
	{
		// Langue saved in conf file or in session
		$lang_site = $userConf['lang'];
	}
	$user->setLang($lang_site);
	$lang = array();
	$lang_path = $path . 'lang/' . $lang_site . '/'. $lang_site . '.php';
	if(file_exists($lang_path))
	{
		include $lang_path;
	}
	$smarty->assign('lang_site', $lang_site);
	$smarty->assign('langAvailables', $langAvailables);
	$smarty->assign('lang', $lang);

	// Device type
	$gesa = Model_gesa::instanceGESA();
	$smarty->assign('gesa', $gesa->toArray());

	// Sidebar menu
	$sidebarMenu = array(
		'interfaces' => array('lang' => 'MENU_INTERFACES', 'icon' => 'menu_interfaces.svg', 'uri' => '/interfaces.php', 'order' => 10),
		'protocols' => array('lang' => 'MENU_PROTOCOLS', 'icon' => 'menu_protocols.svg', 'uri' => '/protocols.php', 'order' => 20),
		'users' => array('lang' => 'MENU_USERS', 'icon' => 'menu_users.svg', 'uri' => '/users.php', 'order' => 30),
	);
	$smarty->assign('sidebarMenu', $sidebarMenu);

	// Assign paths
	$smarty->assign('WEB_ROOT', WEB_ROOT);
	$smarty->assign('TPL_PATH', TPL_PATH);
	$smarty->assign('LIBS_DIR', LIBS_DIR);
	$smarty->assign('IMG_DIR', IMG_DIR);
	$smarty->assign('CSS_MAIN', CSS_MAIN);
	// Assign common data
	$smarty->assign('web_title', $lang['WEB_TITLE']);
}
catch(GesaException | Exception $e)
{
	$errors[] = $e->getMessage();
}

?>
