// protocols.js

// Self called function to start on file include
(() => {
	document.addEventListener("DOMContentLoaded", () => {
		createTabsPersistant('tabs-protocols-conf');
	});
})();

// Init function on SSH tab load
function initTabSSH(filesDir)
{
	setFormClientValidation('#addConfFile-ssh');
	copyEltTextOnClick($('.sshConf .cell-filename'), 'span', globals.lang.ERR_COPY_FILE_PATH, filesDir);
	addProtocolConfigFile('addConfFile-ssh');
	delProtocolConfigFile($('.deleteFileSSH'));
	setModifyConfSSH($('.modifyFileSSH'));
}

// Init function for ssh keys on SSH tab load
function initTabSSHKeys()
{
	copyEltTextOnClick($('.sshKeys .cell-pubkey'), 'span', globals.lang.ERR_COPY_FILE_PATH);
}

// Init function on powershell tab load
function initTabPW(filesDir)
{
	setFormClientValidation('#addConfFile-powershell');
	copyEltTextOnClick($('.cell-filename'), 'span', globals.lang.ERR_COPY_FILE_PATH, filesDir);
	addProtocolConfigFile('addConfFile-powershell');
	delProtocolConfigFile($('.deleteFilePW'));
	setModifyConfPW($('.modifyFilePW'));
}

// Init function on ipmi tab load
function initTabIPMI(filesDir)
{
	setSelect('#selectPriv-ipmi');
	setSelect('#selectDriver-ipmi');
	setFormClientValidation('#addConfFile-ipmi');
	copyEltTextOnClick($('.cell-filename'), 'span', globals.lang.ERR_COPY_FILE_PATH, filesDir);
	addProtocolConfigFile('addConfFile-ipmi');
	delProtocolConfigFile($('.deleteFileIPMI'));
	setModifyConfIPMI($('.modifyFileIPMI'));
}

// Add protocol config file
function addProtocolConfigFile(formSelector)
{
	$('#' + formSelector).on('submit', async e => {
		e.preventDefault();

		try {
			const formData = getFormValues(formSelector);

			await ajaxPromiseJSON({
				url: 'display.php',
				data: {
					action: 'addProtocolConfFile',
					...formData,
				},
			});

			reloadActiveTab($('#tabs-protocols-conf'));
		} catch (err) {
			displayUserMessage(err);
		}
	});
}

// Delete protocol config file
function delProtocolConfigFile(delButtons)
{
	delButtons.on('click', async function() {
		try {
			await ajaxPromiseJSON({
				url: 'display.php',
				data: {
					action: 'delProtocolConfFile',
					fileName: $(this).attr('data-name'),
				},
			});

			reloadActiveTab($('#tabs-protocols-conf'));
		} catch (err) {
			displayUserMessage(err);
		}
    });
}

// Update protocol config file
function updProtocolConfigFile(updButton, fileName)
{
	updButton.on('click', async function() {
		const row = $(this).closest('tr');
		// Get all inputs values
		let values = {};
		$('input, select', row).each(function()
		{
			values[$(this).attr('name')] = $(this).val();
		});

		try {
			await ajaxPromiseJSON({
				url: 'display.php',
				data: {
					action: 'updProtocolConfFile',
					tab: $(this).closest('form').find('input[name="tab"]').val(),
					fileName,
					...values,
				},
			});

			reloadActiveTab($('#tabs-protocols-conf'));
		} catch (err) {
			displayUserMessage(err);
		}
    });
}

// Common protocols transforms row cells for user config modification
function setModifyConfCommon(row, cells, fileName, customSelectElts=[])
{
	const table = row.closest('table');

	// Hide every span inside cells which will be transformed in input
	Object.values(cells).forEach(cell => {
		$('span', cell).hide();
	});

	// Disable other rows actions
	$('.cell-actions button', table).attr('disabled', true);
	$('tfoot input', table).attr('disabled', true);

	// Modify actions list on table row when passing in update mode
	$('.cell-actions > *', row).hide();
	$('.cell-actions', row).append(
		'<button type="button" class="btnIcon btnValid" title="' + globals.lang.VALIDATE + '"></button>' +
		'<button type="button" class="btnIcon btnRefuse" title="' + globals.lang.CANCEL + '"></button>'
	);
	// Set new actions valid & cancel
	updProtocolConfigFile($('.cell-actions .btnValid', row), fileName);
	$('.cell-actions .btnRefuse', row).on('click', function() {
		// Destroy slim select elements
		customSelectElts.forEach(customSelect => { customSelect.destroy() });
		// Show initial cells content
		Object.values(cells).forEach(cell => {
			// Remove cell input
			$('input', cell).remove();
			// Remove cell select
			$('select', cell).remove();
			// Show initial cell content
			$('span', cell).show();
		});
		// Show initial cell actions content
		$('.btnValid', row).remove();
		$('.btnRefuse', row).remove();
		$('.cell-actions > *', row).show();
		// Enable other rows actions
		$('.cell-actions button', table).attr('disabled', false);
		$('tfoot input', table).attr('disabled', false);
	});
}

// Transform row cells for user config modification on ssh config file
function setModifyConfSSH(updButtons)
{
	updButtons.on('click', function() {
		const row = $(this).closest('tr');
		const cells = {
			host: $('.cell-host', row),
			port: $('.cell-port', row),
			user: $('.cell-user', row),
			passwd: $('.cell-passwd', row),
		};
		const values = {
			host: $('span', cells.host).html(),
			port: $('span', cells.port).html(),
			user: $('span', cells.user).html(),
		};

		setModifyConfCommon(row, cells, $(this).attr('data-name'));

		// Create row update inputs
		cells.host.append('<input type="text" name="host" value="' + values.host + '">');
		cells.port.append('<input type="number" name="port" min="0" max="65535" value="' + values.port + '">');
		cells.user.append('<input type="text" name="user" value="' + values.user + '">');
		cells.passwd.append('<input type="password" name="password" value="">');
    });
}

// Transform row cells for user config modification on powershell config file
function setModifyConfPW(updButtons)
{
	updButtons.on('click', function() {
		const row = $(this).closest('tr');
		const cells = {
			host: $('.cell-host', row),
			user: $('.cell-user', row),
			passwd: $('.cell-passwd', row),
		};
		const values = {
			host: $('span', cells.host).html(),
			user: $('span', cells.user).html(),
		};

		setModifyConfCommon(row, cells, $(this).attr('data-name'));

		// Create row update inputs
		cells.host.append('<input type="text" name="host" value="' + values.host + '">');
		cells.user.append('<input type="text" name="user" value="' + values.user + '">');
		cells.passwd.append('<input type="password" name="password" value="">');
    });
}

// Transform row cells for user config modification on ipmi config file
function setModifyConfIPMI(updButtons)
{
	updButtons.on('click', async function() {
		const row = $(this).closest('tr');
		const cells = {
			user: $('.cell-user', row),
			passwd: $('.cell-passwd', row),
			priv: $('.cell-priv', row),
			driver: $('.cell-driver', row),
		};
		const values = {
			user: $('span', cells.user).html(),
			priv: $('span', cells.priv).html(),
			driver: $('span', cells.driver).html(),
		};

		// Create row update inputs
		cells.user.append('<input type="text" name="user" value="' + values.user + '">');
		cells.passwd.append('<input type="password" name="password" value="">');
		// Privilege select
		let privSelect = $('#selectPriv-ipmi').clone();
		privSelect.attr('id', 'selectPriv-ipmi-upd');
		privSelect.val(values.priv);
		privSelect.show();
		cells.priv.append(privSelect);
		let privSelectElt = setSelect('#selectPriv-ipmi-upd');
		// Driver select
		let driverSelect = $('#selectDriver-ipmi').clone();
		driverSelect.attr('id', 'selectDriver-ipmi-upd');
		driverSelect.find('option').each(function()
		{
			// Set selected option by option text instead of value
			if($(this).text() == values.driver)
			{
				$(this).prop('selected', true);
				// Break each loop
				return false;
			}
		});
		driverSelect.show();
		cells.driver.append(driverSelect);
		let driverSelectElt = setSelect('#selectDriver-ipmi-upd');

		setModifyConfCommon(row, cells, $(this).attr('data-name'), [privSelectElt, driverSelectElt]);
    });
}
